@@ -69,7 +69,9 @@ class Menu_Manager(object):
                 raise FileNotFoundError
         else:
             self.background = py.Surface(size())
-        
+        def func(*arg,**kargs): ...
+        self.play_effect:function = func
+
         global _window
         _window = self
     
@@ -96,6 +98,15 @@ class Menu_Manager(object):
                 self.actual_menu.Update()
             py.display.update()
 
+    def Update(self):
+        while self.running:
+            if self.actual_menu:
+                if self.actual_menu.background == None:
+                    self.screen.blit(self.background,(0,0))
+                else:
+                    self.screen.blit(self.actual_menu.background,(0,0))
+                self.actual_menu.Update()
+
     def stop(self):
         """
         stop the current thread de la classe
@@ -306,17 +317,22 @@ class Button(sprite):
     def __init__(self,name,path,isactive=True,layer=0):
         super().__init__(name,path,isactive,layer)
 
-    def on_click(self,func):
+    def on_click(self,_effect=None):
         """
         nouvelle fonction qui n'executera que la fonction en cas de click du boutton
         la nouvelle fonction est ajouté dans la liste des function à executé
         """
-        def wrap(_event:py.event.Event,*args,**kargs):   
-            if _event.type == py.MOUSEBUTTONUP:
-                if self.rect.collidepoint(py.mouse.get_pos()):
-                    if self.check_layer():
-                        return func(*args,**kargs)
-        self.handles.append(wrap)
+        def Wrap(func):
+            def wrap(_event:py.event.Event,*args,**kargs):   
+                if _event.type == py.MOUSEBUTTONUP:
+                    if self.rect.collidepoint(py.mouse.get_pos()):
+                        if self.check_layer():
+                            func(*args,**kargs)
+                            if _effect != None:
+                                _window.play_effect(_effect)
+            self.handles.append(wrap)
+        
+        return Wrap
     
     def check_layer(self):
         for _sprite in _window.actual_menu.sprites:
